| add_snippet | R Documentation |
Convert code to code snippet
add_snippet(
script = system.file("conversion_staging.R", package = "advancedShiny")
)
script |
the R script to convert to a code snippet |
inserts the code necessary as a code snippet below the current selection
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.