code_snippet: Include code snippets

View source: R/fct_code.R

code_snippetR Documentation

Include code snippets

Description

Generate formatted markdown with a copy to clipboard button to allow users to copy code to their clipboard.

Usage

code_snippet(vec)

Arguments

vec

a character vector of code (one element per line) to be shown

Value

a HTML string which can be inserted directly into the UI of the app, showing the code as a formatted snippet along with a 'Copy' button


chrisbrownlie/advancedShiny documentation built on Aug. 2, 2022, 3:29 a.m.