| code_snippet | R Documentation |
Generate formatted markdown with a copy to clipboard button to allow users to copy code to their clipboard.
code_snippet(vec)
vec |
a character vector of code (one element per line) to be shown |
a HTML string which can be inserted directly into the UI of the app, showing the code as a formatted snippet along with a 'Copy' button
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.